@@ -75,8 +75,9 @@ int synth_1to1_i586_asm(real *bandPtr, int channel, unsigned char *out, unsigned
 int synth_1to1_i586(real *bandPtr, int channel, mpg123_handle *fr, int final)
 {
 	int ret;
+#ifndef NO_EQUALIZER
 	if(fr->have_eq_settings) do_equalizer(bandPtr,channel,fr->equalizer);
-
+#endif
 	ret = synth_1to1_i586_asm(bandPtr, channel, fr->buffer.data+fr->buffer.fill, fr->rawbuffs, &fr->bo, fr->decwin);
 	if(final) fr->buffer.fill += 128;
 	return ret;
@@ -91,8 +92,9 @@ int synth_1to1_i586_dither(real *bandPtr, int channel, mpg123_handle *fr, int fi
 {
 	int ret;
 	int bo_dither[2]; /* Temporary workaround? Could expand the asm code. */
+#ifndef NO_EQUALIZER
 	if(fr->have_eq_settings) do_equalizer(bandPtr,channel,fr->equalizer);
-
+#endif
 	/* Applying this hack, to change the asm only bit by bit (adding dithernoise pointer). */
 	bo_dither[0] = fr->bo;
 	bo_dither[1] = fr->ditherindex;
@@ -105,7 +107,7 @@ int synth_1to1_i586_dither(real *bandPtr, int channel, mpg123_handle *fr, int fi
 }
 #endif
 
-#ifdef OPT_3DNOW
+#if defined(OPT_3DNOW) || defined(OPT_3DNOW_VINTAGE)
 /* Those are defined in assembler. */
 void do_equalizer_3dnow(real *bandPtr,int channel, real equalizer[2][32]);
 int synth_1to1_3dnow_asm(real *bandPtr, int channel, unsigned char *out, unsigned char *buffs, int *bo, real *decwin);
@@ -113,9 +115,9 @@ int synth_1to1_3dnow_asm(real *bandPtr, int channel, unsigned char *out, unsigne
 int synth_1to1_3dnow(real *bandPtr, int channel, mpg123_handle *fr, int final)
 {
 	int ret;
-
+#ifndef NO_EQUALIZER
 	if(fr->have_eq_settings) do_equalizer_3dnow(bandPtr,channel,fr->equalizer);
-
+#endif
 	/* this is in asm, can be dither or not */
 	/* uh, is this return from pointer correct? */ 
 	ret = (int) synth_1to1_3dnow_asm(bandPtr, channel, fr->buffer.data+fr->buffer.fill, fr->rawbuffs, &fr->bo, fr->decwin);
@@ -130,8 +132,9 @@ int synth_1to1_MMX(real *bandPtr, int channel, short *out, short *buffs, int *bo
 /* This is just a hull to use the mpg123 handle. */
 int synth_1to1_mmx(real *bandPtr, int channel, mpg123_handle *fr, int final)
 {
+#ifndef NO_EQUALIZER
 	if(fr->have_eq_settings) do_equalizer(bandPtr,channel,fr->equalizer);
-
+#endif
 	/* in asm */
 	synth_1to1_MMX(bandPtr, channel, (short*) (fr->buffer.data+fr->buffer.fill), (short *) fr->rawbuffs, &fr->bo, fr->decwins);
 	if(final) fr->buffer.fill += 128;
@@ -139,7 +142,7 @@ int synth_1to1_mmx(real *bandPtr, int channel, mpg123_handle *fr, int final)
 }
 #endif
 
-#ifdef OPT_SSE
+#if defined(OPT_SSE) || defined(OPT_SSE_VINTAGE)
 #ifdef ACCURATE_ROUNDING
 /* This is defined in assembler. */
 int synth_1to1_sse_accurate_asm(real *window, real *b0, short *samples, int bo1);
@@ -152,9 +155,9 @@ int synth_1to1_sse(real *bandPtr,int channel, mpg123_handle *fr, int final)
 	real *b0, **buf;
 	int clip; 
 	int bo1;
-
+#ifndef NO_EQUALIZER
 	if(fr->have_eq_settings) do_equalizer(bandPtr,channel,fr->equalizer);
-
+#endif
 	if(!channel)
 	{
 		fr->bo--;
@@ -194,13 +197,13 @@ int synth_1to1_stereo_sse(real *bandPtr_l, real *bandPtr_r, mpg123_handle *fr)
 	real *b0l, *b0r, **bufl, **bufr;
 	int bo1;
 	int clip;
-
+#ifndef NO_EQUALIZER
 	if(fr->have_eq_settings)
 	{
 		do_equalizer(bandPtr_l,0,fr->equalizer);
 		do_equalizer(bandPtr_r,1,fr->equalizer);
 	}
-
+#endif
 	fr->bo--;
 	fr->bo &= 0xf;
 	bufl = fr->real_buffs[0];
@@ -235,8 +238,9 @@ void synth_1to1_sse_asm(real *bandPtr, int channel, short *samples, short *buffs
 /* This is just a hull to use the mpg123 handle. */
 int synth_1to1_sse(real *bandPtr, int channel, mpg123_handle *fr, int final)
 {
+#ifndef NO_EQUALIZER
 	if(fr->have_eq_settings) do_equalizer(bandPtr,channel,fr->equalizer);
-
+#endif
 	synth_1to1_sse_asm(bandPtr, channel, (short*) (fr->buffer.data+fr->buffer.fill), (short *) fr->rawbuffs, &fr->bo, fr->decwins);
 	if(final) fr->buffer.fill += 128;
 	return 0;
@@ -244,14 +248,15 @@ int synth_1to1_sse(real *bandPtr, int channel, mpg123_handle *fr, int final)
 #endif
 #endif
 
-#ifdef OPT_3DNOWEXT
+#if defined(OPT_3DNOWEXT) || defined(OPT_3DNOWEXT_VINTAGE)
 /* This is defined in assembler. */
 void synth_1to1_3dnowext_asm(real *bandPtr, int channel, short *samples, short *buffs, int *bo, real *decwin);
 /* This is just a hull to use the mpg123 handle. */
 int synth_1to1_3dnowext(real *bandPtr, int channel, mpg123_handle *fr, int final)
 {
+#ifndef NO_EQUALIZER
 	if(fr->have_eq_settings) do_equalizer(bandPtr,channel,fr->equalizer);
-
+#endif
 	synth_1to1_3dnowext_asm(bandPtr, channel, (short*) (fr->buffer.data+fr->buffer.fill), (short *) fr->rawbuffs, &fr->bo, fr->decwins);
 	if(final) fr->buffer.fill += 128;
 	return 0;
@@ -272,9 +277,9 @@ int synth_1to1_x86_64(real *bandPtr,int channel, mpg123_handle *fr, int final)
 	real *b0, **buf;
 	int bo1;
 	int clip;
-
+#ifndef NO_EQUALIZER
 	if(fr->have_eq_settings) do_equalizer(bandPtr,channel,fr->equalizer);
-
+#endif
 	if(!channel)
 	{
 		fr->bo--;
@@ -314,13 +319,13 @@ int synth_1to1_stereo_x86_64(real *bandPtr_l, real *bandPtr_r, mpg123_handle *fr
 	real *b0l, *b0r, **bufl, **bufr;
 	int bo1;
 	int clip;
-
+#ifndef NO_EQUALIZER
 	if(fr->have_eq_settings)
 	{
 		do_equalizer(bandPtr_l,0,fr->equalizer);
 		do_equalizer(bandPtr_r,1,fr->equalizer);
 	}
-
+#endif
 	fr->bo--;
 	fr->bo &= 0xf;
 	bufl = fr->real_buffs[0];
@@ -361,9 +366,9 @@ int synth_1to1_x86_64(real *bandPtr,int channel, mpg123_handle *fr, int final)
 	short *b0, **buf;
 	int clip; 
 	int bo1;
-
+#ifndef NO_EQUALIZER
 	if(fr->have_eq_settings) do_equalizer(bandPtr,channel,fr->equalizer);
-
+#endif
 	if(!channel)
 	{
 		fr->bo--;
@@ -402,13 +407,13 @@ int synth_1to1_stereo_x86_64(real *bandPtr_l,real *bandPtr_r, mpg123_handle *fr)
 	short *b0l, *b0r, **bufl, **bufr;
 	int clip; 
 	int bo1;
-
+#ifndef NO_EQUALIZER
 	if(fr->have_eq_settings)
 	{
 		do_equalizer(bandPtr_l,0,fr->equalizer);
 		do_equalizer(bandPtr_r,1,fr->equalizer);
 	}
-
+#endif
 	fr->bo--;
 	fr->bo &= 0xf;
 	bufl = fr->short_buffs[0];
@@ -440,6 +445,192 @@ int synth_1to1_stereo_x86_64(real *bandPtr_l,real *bandPtr_r, mpg123_handle *fr)
 #endif
 #endif
 
+#ifdef OPT_AVX
+#ifdef ACCURATE_ROUNDING
+/* Assembler routines. */
+#ifndef OPT_X86_64
+int synth_1to1_x86_64_accurate_asm(real *window, real *b0, short *samples, int bo1);
+#endif
+int synth_1to1_s_avx_accurate_asm(real *window, real *b0l, real *b0r, short *samples, int bo1);
+void dct64_real_avx(real *out0, real *out1, real *samples);
+/* Hull for C mpg123 API */
+int synth_1to1_avx(real *bandPtr,int channel, mpg123_handle *fr, int final)
+{
+	short *samples = (short *) (fr->buffer.data+fr->buffer.fill);
+
+	real *b0, **buf;
+	int bo1;
+	int clip;
+#ifndef NO_EQUALIZER
+	if(fr->have_eq_settings) do_equalizer(bandPtr,channel,fr->equalizer);
+#endif
+	if(!channel)
+	{
+		fr->bo--;
+		fr->bo &= 0xf;
+		buf = fr->real_buffs[0];
+	}
+	else
+	{
+		samples++;
+		buf = fr->real_buffs[1];
+	}
+
+	if(fr->bo & 0x1)
+	{
+		b0 = buf[0];
+		bo1 = fr->bo;
+		dct64_real_avx(buf[1]+((fr->bo+1)&0xf),buf[0]+fr->bo,bandPtr);
+	}
+	else
+	{
+		b0 = buf[1];
+		bo1 = fr->bo+1;
+		dct64_real_avx(buf[0]+fr->bo,buf[1]+fr->bo+1,bandPtr);
+	}
+
+	clip = synth_1to1_x86_64_accurate_asm(fr->decwin, b0, samples, bo1);
+
+	if(final) fr->buffer.fill += 128;
+
+	return clip;
+}
+
+int synth_1to1_stereo_avx(real *bandPtr_l, real *bandPtr_r, mpg123_handle *fr)
+{
+	short *samples = (short *) (fr->buffer.data+fr->buffer.fill);
+
+	real *b0l, *b0r, **bufl, **bufr;
+	int bo1;
+	int clip;
+#ifndef NO_EQUALIZER
+	if(fr->have_eq_settings)
+	{
+		do_equalizer(bandPtr_l,0,fr->equalizer);
+		do_equalizer(bandPtr_r,1,fr->equalizer);
+	}
+#endif
+	fr->bo--;
+	fr->bo &= 0xf;
+	bufl = fr->real_buffs[0];
+	bufr = fr->real_buffs[1];
+
+	if(fr->bo & 0x1)
+	{
+		b0l = bufl[0];
+		b0r = bufr[0];
+		bo1 = fr->bo;
+		dct64_real_avx(bufl[1]+((fr->bo+1)&0xf),bufl[0]+fr->bo,bandPtr_l);
+		dct64_real_avx(bufr[1]+((fr->bo+1)&0xf),bufr[0]+fr->bo,bandPtr_r);
+	}
+	else
+	{
+		b0l = bufl[1];
+		b0r = bufr[1];
+		bo1 = fr->bo+1;
+		dct64_real_avx(bufl[0]+fr->bo,bufl[1]+fr->bo+1,bandPtr_l);
+		dct64_real_avx(bufr[0]+fr->bo,bufr[1]+fr->bo+1,bandPtr_r);
+	}
+
+	clip = synth_1to1_s_avx_accurate_asm(fr->decwin, b0l, b0r, samples, bo1);
+
+	fr->buffer.fill += 128;
+
+	return clip;
+}
+#else
+/* This is defined in assembler. */
+#ifndef OPT_X86_64
+int synth_1to1_x86_64_asm(short *window, short *b0, short *samples, int bo1);
+#endif
+int synth_1to1_s_avx_asm(short *window, short *b0l, short *b0r, short *samples, int bo1);
+void dct64_avx(short *out0, short *out1, real *samples);
+/* This is just a hull to use the mpg123 handle. */
+int synth_1to1_avx(real *bandPtr,int channel, mpg123_handle *fr, int final)
+{
+	short *samples = (short *) (fr->buffer.data+fr->buffer.fill);	
+	short *b0, **buf;
+	int clip; 
+	int bo1;
+#ifndef NO_EQUALIZER
+	if(fr->have_eq_settings) do_equalizer(bandPtr,channel,fr->equalizer);
+#endif
+	if(!channel)
+	{
+		fr->bo--;
+		fr->bo &= 0xf;
+		buf = fr->short_buffs[0];
+	}
+	else
+	{
+		samples++;
+		buf = fr->short_buffs[1];
+	}
+
+	if(fr->bo & 0x1) 
+	{
+		b0 = buf[0];
+		bo1 = fr->bo;
+		dct64_avx(buf[1]+((fr->bo+1)&0xf),buf[0]+fr->bo,bandPtr);
+	}
+	else
+	{
+		b0 = buf[1];
+		bo1 = fr->bo+1;
+		dct64_avx(buf[0]+fr->bo,buf[1]+fr->bo+1,bandPtr);
+	}
+
+	clip = synth_1to1_x86_64_asm((short *)fr->decwins, b0, samples, bo1);
+
+	if(final) fr->buffer.fill += 128;
+
+	return clip;
+}
+
+int synth_1to1_stereo_avx(real *bandPtr_l,real *bandPtr_r, mpg123_handle *fr)
+{
+	short *samples = (short *) (fr->buffer.data+fr->buffer.fill);
+	short *b0l, *b0r, **bufl, **bufr;
+	int clip; 
+	int bo1;
+#ifndef NO_EQUALIZER
+	if(fr->have_eq_settings)
+	{
+		do_equalizer(bandPtr_l,0,fr->equalizer);
+		do_equalizer(bandPtr_r,1,fr->equalizer);
+	}
+#endif
+	fr->bo--;
+	fr->bo &= 0xf;
+	bufl = fr->short_buffs[0];
+	bufr = fr->short_buffs[1];
+
+	if(fr->bo & 0x1) 
+	{
+		b0l = bufl[0];
+		b0r = bufr[0];
+		bo1 = fr->bo;
+		dct64_avx(bufl[1]+((fr->bo+1)&0xf),bufl[0]+fr->bo,bandPtr_l);
+		dct64_avx(bufr[1]+((fr->bo+1)&0xf),bufr[0]+fr->bo,bandPtr_r);
+	}
+	else
+	{
+		b0l = bufl[1];
+		b0r = bufr[1];
+		bo1 = fr->bo+1;
+		dct64_avx(bufl[0]+fr->bo,bufl[1]+fr->bo+1,bandPtr_l);
+		dct64_avx(bufr[0]+fr->bo,bufr[1]+fr->bo+1,bandPtr_r);
+	}
+
+	clip = synth_1to1_s_avx_asm((short *)fr->decwins, b0l, b0r, samples, bo1);
+
+	fr->buffer.fill += 128;
+
+	return clip;
+}
+#endif
+#endif
+
 #ifdef OPT_ARM
 #ifdef ACCURATE_ROUNDING
 /* Assembler routines. */
@@ -452,9 +643,9 @@ int synth_1to1_arm(real *bandPtr,int channel, mpg123_handle *fr, int final)
 	real *b0, **buf;
 	int bo1;
 	int clip;
-
+#ifndef NO_EQUALIZER
 	if(fr->have_eq_settings) do_equalizer(bandPtr,channel,fr->equalizer);
-
+#endif
 	if(!channel)
 	{
 		fr->bo--;
@@ -497,9 +688,9 @@ int synth_1to1_arm(real *bandPtr,int channel, mpg123_handle *fr, int final)
 	real *b0, **buf;
 	int bo1;
 	int clip;
-
+#ifndef NO_EQUALIZER
 	if(fr->have_eq_settings) do_equalizer(bandPtr,channel,fr->equalizer);
-
+#endif
 	if(!channel)
 	{
 		fr->bo--;
@@ -548,9 +739,9 @@ int synth_1to1_neon(real *bandPtr,int channel, mpg123_handle *fr, int final)
 	real *b0, **buf;
 	int bo1;
 	int clip;
-
+#ifndef NO_EQUALIZER
 	if(fr->have_eq_settings) do_equalizer(bandPtr,channel,fr->equalizer);
-
+#endif
 	if(!channel)
 	{
 		fr->bo--;
@@ -590,13 +781,13 @@ int synth_1to1_stereo_neon(real *bandPtr_l, real *bandPtr_r, mpg123_handle *fr)
 	real *b0l, *b0r, **bufl, **bufr;
 	int bo1;
 	int clip;
-
+#ifndef NO_EQUALIZER
 	if(fr->have_eq_settings)
 	{
 		do_equalizer(bandPtr_l,0,fr->equalizer);
 		do_equalizer(bandPtr_r,1,fr->equalizer);
 	}
-
+#endif
 	fr->bo--;
 	fr->bo &= 0xf;
 	bufl = fr->real_buffs[0];
@@ -637,9 +828,9 @@ int synth_1to1_neon(real *bandPtr,int channel, mpg123_handle *fr, int final)
 	short *b0, **buf;
 	int clip; 
 	int bo1;
-
+#ifndef NO_EQUALIZER
 	if(fr->have_eq_settings) do_equalizer(bandPtr,channel,fr->equalizer);
-
+#endif
 	if(!channel)
 	{
 		fr->bo--;
@@ -678,13 +869,13 @@ int synth_1to1_stereo_neon(real *bandPtr_l,real *bandPtr_r, mpg123_handle *fr)
 	short *b0l, *b0r, **bufl, **bufr;
 	int clip; 
 	int bo1;
-
+#ifndef NO_EQUALIZER
 	if(fr->have_eq_settings)
 	{
 		do_equalizer(bandPtr_l,0,fr->equalizer);
 		do_equalizer(bandPtr_r,1,fr->equalizer);
 	}
-
+#endif
 	fr->bo--;
 	fr->bo &= 0xf;
 	bufl = fr->short_buffs[0];
@@ -716,6 +907,188 @@ int synth_1to1_stereo_neon(real *bandPtr_l,real *bandPtr_r, mpg123_handle *fr)
 #endif
 #endif
 
+#ifdef OPT_NEON64
+#ifdef ACCURATE_ROUNDING
+/* This is defined in assembler. */
+int synth_1to1_neon64_accurate_asm(real *window, real *b0, short *samples, int bo1);
+int synth_1to1_s_neon64_accurate_asm(real *window, real *b0l, real *b0r, short *samples, int bo1);
+void dct64_real_neon64(real *out0, real *out1, real *samples);
+/* Hull for C mpg123 API */
+int synth_1to1_neon64(real *bandPtr,int channel, mpg123_handle *fr, int final)
+{
+	short *samples = (short *) (fr->buffer.data+fr->buffer.fill);
+
+	real *b0, **buf;
+	int bo1;
+	int clip;
+#ifndef NO_EQUALIZER
+	if(fr->have_eq_settings) do_equalizer(bandPtr,channel,fr->equalizer);
+#endif
+	if(!channel)
+	{
+		fr->bo--;
+		fr->bo &= 0xf;
+		buf = fr->real_buffs[0];
+	}
+	else
+	{
+		samples++;
+		buf = fr->real_buffs[1];
+	}
+
+	if(fr->bo & 0x1)
+	{
+		b0 = buf[0];
+		bo1 = fr->bo;
+		dct64_real_neon64(buf[1]+((fr->bo+1)&0xf),buf[0]+fr->bo,bandPtr);
+	}
+	else
+	{
+		b0 = buf[1];
+		bo1 = fr->bo+1;
+		dct64_real_neon64(buf[0]+fr->bo,buf[1]+fr->bo+1,bandPtr);
+	}
+
+	clip = synth_1to1_neon64_accurate_asm(fr->decwin, b0, samples, bo1);
+
+	if(final) fr->buffer.fill += 128;
+
+	return clip;
+}
+
+int synth_1to1_stereo_neon64(real *bandPtr_l, real *bandPtr_r, mpg123_handle *fr)
+{
+	short *samples = (short *) (fr->buffer.data+fr->buffer.fill);
+
+	real *b0l, *b0r, **bufl, **bufr;
+	int bo1;
+	int clip;
+#ifndef NO_EQUALIZER
+	if(fr->have_eq_settings)
+	{
+		do_equalizer(bandPtr_l,0,fr->equalizer);
+		do_equalizer(bandPtr_r,1,fr->equalizer);
+	}
+#endif
+	fr->bo--;
+	fr->bo &= 0xf;
+	bufl = fr->real_buffs[0];
+	bufr = fr->real_buffs[1];
+
+	if(fr->bo & 0x1)
+	{
+		b0l = bufl[0];
+		b0r = bufr[0];
+		bo1 = fr->bo;
+		dct64_real_neon64(bufl[1]+((fr->bo+1)&0xf),bufl[0]+fr->bo,bandPtr_l);
+		dct64_real_neon64(bufr[1]+((fr->bo+1)&0xf),bufr[0]+fr->bo,bandPtr_r);
+	}
+	else
+	{
+		b0l = bufl[1];
+		b0r = bufr[1];
+		bo1 = fr->bo+1;
+		dct64_real_neon64(bufl[0]+fr->bo,bufl[1]+fr->bo+1,bandPtr_l);
+		dct64_real_neon64(bufr[0]+fr->bo,bufr[1]+fr->bo+1,bandPtr_r);
+	}
+
+	clip = synth_1to1_s_neon64_accurate_asm(fr->decwin, b0l, b0r, samples, bo1);
+
+	fr->buffer.fill += 128;
+
+	return clip;
+}
+#else
+/* This is defined in assembler. */
+int synth_1to1_neon64_asm(short *window, short *b0, short *samples, int bo1);
+int synth_1to1_s_neon64_asm(short *window, short *b0l, short *b0r, short *samples, int bo1);
+void dct64_neon64(short *out0, short *out1, real *samples);
+/* Hull for C mpg123 API */
+int synth_1to1_neon64(real *bandPtr,int channel, mpg123_handle *fr, int final)
+{
+	short *samples = (short *) (fr->buffer.data+fr->buffer.fill);	
+	short *b0, **buf;
+	int clip; 
+	int bo1;
+#ifndef NO_EQUALIZER
+	if(fr->have_eq_settings) do_equalizer(bandPtr,channel,fr->equalizer);
+#endif
+	if(!channel)
+	{
+		fr->bo--;
+		fr->bo &= 0xf;
+		buf = fr->short_buffs[0];
+	}
+	else
+	{
+		samples++;
+		buf = fr->short_buffs[1];
+	}
+
+	if(fr->bo & 0x1) 
+	{
+		b0 = buf[0];
+		bo1 = fr->bo;
+		dct64_neon64(buf[1]+((fr->bo+1)&0xf),buf[0]+fr->bo,bandPtr);
+	}
+	else
+	{
+		b0 = buf[1];
+		bo1 = fr->bo+1;
+		dct64_neon64(buf[0]+fr->bo,buf[1]+fr->bo+1,bandPtr);
+	}
+
+	clip = synth_1to1_neon64_asm((short *)fr->decwins, b0, samples, bo1);
+
+	if(final) fr->buffer.fill += 128;
+
+	return clip;
+}
+
+int synth_1to1_stereo_neon64(real *bandPtr_l,real *bandPtr_r, mpg123_handle *fr)
+{
+	short *samples = (short *) (fr->buffer.data+fr->buffer.fill);
+	short *b0l, *b0r, **bufl, **bufr;
+	int clip; 
+	int bo1;
+#ifndef NO_EQUALIZER
+	if(fr->have_eq_settings)
+	{
+		do_equalizer(bandPtr_l,0,fr->equalizer);
+		do_equalizer(bandPtr_r,1,fr->equalizer);
+	}
+#endif
+	fr->bo--;
+	fr->bo &= 0xf;
+	bufl = fr->short_buffs[0];
+	bufr = fr->short_buffs[1];
+
+	if(fr->bo & 0x1) 
+	{
+		b0l = bufl[0];
+		b0r = bufr[0];
+		bo1 = fr->bo;
+		dct64_neon64(bufl[1]+((fr->bo+1)&0xf),bufl[0]+fr->bo,bandPtr_l);
+		dct64_neon64(bufr[1]+((fr->bo+1)&0xf),bufr[0]+fr->bo,bandPtr_r);
+	}
+	else
+	{
+		b0l = bufl[1];
+		b0r = bufr[1];
+		bo1 = fr->bo+1;
+		dct64_neon64(bufl[0]+fr->bo,bufl[1]+fr->bo+1,bandPtr_l);
+		dct64_neon64(bufr[0]+fr->bo,bufr[1]+fr->bo+1,bandPtr_r);
+	}
+
+	clip = synth_1to1_s_neon64_asm((short *)fr->decwins, b0l, b0r, samples, bo1);
+
+	fr->buffer.fill += 128;
+
+	return clip;
+}
+#endif
+#endif
+
 #ifndef NO_DOWNSAMPLE
 
 /*
