@@ -14,6 +14,11 @@ case $build_type in
     strip=strip
     hostopt=
   ;;
+  x86-cross)
+    decoder=x86
+    strip=i686-w64-mingw32-strip
+    hostopt="--host=i686-w64-mingw32 --build=`./build/config.guess`"
+  ;;
   x86_64-cross)
     decoder=x86-64
     strip=x86_64-w64-mingw32-strip
@@ -98,6 +103,7 @@ mpg123_build()
 	rm -rf "$final/$name" &&
 	mkdir  "$final/$name" &&
 	cp -v "$tmp/bin/mpg123.exe" "$final/$name" &&
+	cp -v "$tmp/bin/out123.exe" "$final/$name" &&
 	if test "$debug" = y; then
 		echo "Not stripping the debug build..."
 	else
@@ -106,7 +112,7 @@ mpg123_build()
 	if test "$stat" = "y"; then
 		echo "No DLL there..."
 	else
-		cp -v "$tmp/bin/libmpg123"*.dll "$tmp/include/mpg123.h" "$final/$name" &&
+		cp -v "$tmp/bin/lib*123"*.dll "$tmp/include/*123*.h" "$final/$name" &&
 		cp -v "src/libmpg123/.libs/libmpg123"*.dll.def "$final/$name" &&
 		if test "$debug" = y; then
 			echo "Not stripping the debug build..."
@@ -116,7 +122,9 @@ mpg123_build()
 		for i in $tmp/lib/mpg123/*.dll
 		do
 			if test -e "$i"; then
-				cp -v "$i" "$final/$name/plugins"
+				plugdir="$final/$name/plugins"
+				mkdir -p "$plugdir" &&
+				cp -v "$i" "$plugdir"
 			fi
 		done
 	fi &&
